BOARD = 'board'
ATTACH = 'attach'
DETAILS = 'details'
LIST = 'list'
LISTALL = 'listall'
COMPILE = 'compile'
CONFIG = 'config'
DUMP = 'dump'
INIT = 'init'
CORE = 'core'
DOWNLOAD = 'download'
INSTALL = 'install'
SEARCH = 'search'
UNINSTALL = 'uninstall'
UPDATE_INDEX = 'update-index'
UPGRADE = 'upgrade'
DAEMON = 'daemon'
LIB = 'lib'
SKETCH = 'sketch'
NEW = 'new'
UPLOAD = 'upload'
VERSION = 'version'
DEPS = 'deps'
CACHE = 'cache'
CLEAN = 'clean'
DEBUG = 'debug'
BURN_BOOTLOADER = 'burn-bootloader'
COMPLETION = 'completion'
EXAMPLES = 'examples'
OUTDATED = 'outdated'
ARCHIVE = 'archive'
UPDATE = 'update'
ADD = 'add'
DELETE = 'delete'
REMOVE = 'remove'
SET = 'set'
